@@ -3,6 +3,9 @@ from typing import (
     Iterator,
     Iterable,
     List,
+    Optional,
+    Union,
+    cast,
     overload,
     TypeVar,
     TYPE_CHECKING,
@@ -28,7 +31,9 @@ T = TypeVar("T")
 class Renderables:
     """A list subclass which renders its contents to the console."""
 
-    def __init__(self, renderables: Iterable["RenderableType"] = None) -> None:
+    def __init__(
+        self, renderables: Optional[Iterable["RenderableType"]] = None
+    ) -> None:
         self._renderables: List["RenderableType"] = (
             list(renderables) if renderables is not None else []
         )
@@ -39,9 +44,11 @@ class Renderables:
         """Console render method to insert line-breaks."""
         yield from self._renderables
 
-    def __rich_measure__(self, console: "Console", max_width: int) -> "Measurement":
+    def __rich_measure__(
+        self, console: "Console", options: "ConsoleOptions"
+    ) -> "Measurement":
         dimensions = [
-            Measurement.get(console, renderable, max_width)
+            Measurement.get(console, options, renderable)
             for renderable in self._renderables
         ]
         if not dimensions:
@@ -74,10 +81,10 @@ class Lines:
         ...
 
     @overload
-    def __getitem__(self, index: slice) -> "Lines":
+    def __getitem__(self, index: slice) -> List["Text"]:
         ...
 
-    def __getitem__(self, index):
+    def __getitem__(self, index: Union[slice, int]) -> Union["Text", List["Text"]]:
         return self._lines[index]
 
     def __setitem__(self, index: int, value: "Text") -> "Lines":
@@ -99,6 +106,9 @@ class Lines:
     def extend(self, lines: Iterable["Text"]) -> None:
         self._lines.extend(lines)
 
+    def pop(self, index: int = -1) -> "Text":
+        return self._lines.pop(index)
+
     def justify(
         self,
         console: "Console",
